package org.dromara.ems.record.service.impl;

import org.dromara.ems.record.domain.EmsVibrationInstant;
import org.dromara.ems.record.mapper.EmsVibrationInstantMapper;
import org.dromara.ems.record.service.IEmsVibrationInstantService;
import lombok.RequiredArgsConstructor;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 震动实时数据Service业务层处理
 * 
 * @author ZangCH
 * @date 2024-08-22
 */
@Service
@RequiredArgsConstructor
public class EmsVibrationInstantServiceImpl implements IEmsVibrationInstantService 
{
    
    private final EmsVibrationInstantMapper emsVibrationInstantMapper;

    /**
     * 查询震动实时数据
     * 
     * @param objId 震动实时数据主键
     * @return 震动实时数据
     */
    @Override
    public EmsVibrationInstant selectEmsVibrationInstantByObjId(Long objId)
    {
        return emsVibrationInstantMapper.selectEmsVibrationInstantByObjId(objId);
    }

    /**
     * 查询震动实时数据列表
     * 
     * @param emsVibrationInstant 震动实时数据
     * @return 震动实时数据
     */
    @Override
    public List<EmsVibrationInstant> selectEmsVibrationInstantList(EmsVibrationInstant emsVibrationInstant)
    {
        return emsVibrationInstantMapper.selectEmsVibrationInstantList(emsVibrationInstant);
    }

    /**
     * 新增震动实时数据
     * 
     * @param emsVibrationInstant 震动实时数据
     * @return 结果
     */
    @Override
    public int insertEmsVibrationInstant(EmsVibrationInstant emsVibrationInstant)
    {
        return emsVibrationInstantMapper.insertEmsVibrationInstant(emsVibrationInstant);
    }

    /**
     * 修改震动实时数据
     * 
     * @param emsVibrationInstant 震动实时数据
     * @return 结果
     */
    @Override
    public int updateEmsVibrationInstant(EmsVibrationInstant emsVibrationInstant)
    {
        return emsVibrationInstantMapper.updateEmsVibrationInstant(emsVibrationInstant);
    }

    /**
     * 批量删除震动实时数据
     * 
     * @param objIds 需要删除的震动实时数据主键
     * @return 结果
     */
    @Override
    public int deleteEmsVibrationInstantByObjIds(Long[] objIds)
    {
        return emsVibrationInstantMapper.deleteEmsVibrationInstantByObjIds(objIds);
    }

    /**
     * 删除震动实时数据信息
     * 
     * @param objId 震动实时数据主键
     * @return 结果
     */
    @Override
    public int deleteEmsVibrationInstantByObjId(Long objId)
    {
        return emsVibrationInstantMapper.deleteEmsVibrationInstantByObjId(objId);
    }

    /**impl
     * 查询震动实时数据
     * @param emsVibrationInstant
     * @return
     */
    @Override
    public List<EmsVibrationInstant> selectVibrationInstantList(EmsVibrationInstant emsVibrationInstant) {
        return emsVibrationInstantMapper.selectVibrationInstantList(emsVibrationInstant);
    }
}
